WasmMockQuerier

Struct WasmMockQuerier 

pub struct WasmMockQuerier { /* private fields */ }
Querier struct that fetches queries on-chain directly

Implementations

Source

impl WasmMockQuerier

pub fn handle_query( &self, request: &QueryRequest, ) -> SystemResult<ContractResult<Binary>>

Function used to handle a query and customize the query behavior This implements some queries by querying an actual node for the responses

Source

impl WasmMockQuerier

pub fn new(chain: ChainInfoBase<String, Vec<String>>) -> WasmMockQuerier

Creates a querier from chain information